<?php

namespace Litecms\ManageBusListing\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\ManageBusListing\Http\Requests\ManageBusListingRequest;
use Litecms\ManageBusListing\Interfaces\ManageBusListingRepositoryInterface;
use Litecms\ManageBusListing\Models\ManageBusListing;

/**
 * Resource controller class for manage_bus_listing.
 */
class ManageBusListingResourceController extends BaseController
{

    /**
     * Initialize manage_bus_listing resource controller.
     *
     * @param type ManageBusListingRepositoryInterface $manage_bus_listing
     *
     * @return null
     */
    public function __construct(ManageBusListingRepositoryInterface $manage_bus_listing)
    {
        parent::__construct();
        $this->repository = $manage_bus_listing;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\ManageBusListing\Repositories\Criteria\ManageBusListingResourceCriteria::class);
    }

    /**
     * Display a list of manage_bus_listing.
     *
     * @return Response
     */
    public function index(ManageBusListingRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\ManageBusListing\Repositories\Presenter\ManageBusListingPresenter::class)
                ->$function();
        }

        $manage_bus_listings = $this->repository->paginate();

        return $this->response->title(trans('manage_bus_listing::manage_bus_listing.names'))
            ->view('manage_bus_listing::manage_bus_listing.index', true)
            ->data(compact('manage_bus_listings'))
            ->output();
    }

    /**
     * Display manage_bus_listing.
     *
     * @param Request $request
     * @param Model   $manage_bus_listing
     *
     * @return Response
     */
    public function show(ManageBusListingRequest $request, ManageBusListing $manage_bus_listing)
    {

        if ($manage_bus_listing->exists) {
            $view = 'manage_bus_listing::manage_bus_listing.show';
        } else {
            $view = 'manage_bus_listing::manage_bus_listing.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('manage_bus_listing::manage_bus_listing.name'))
            ->data(compact('manage_bus_listing'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new manage_bus_listing.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ManageBusListingRequest $request)
    {

        $manage_bus_listing = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('manage_bus_listing::manage_bus_listing.name')) 
            ->view('manage_bus_listing::manage_bus_listing.create', true) 
            ->data(compact('manage_bus_listing'))
            ->output();
    }

    /**
     * Create new manage_bus_listing.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ManageBusListingRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $manage_bus_listing                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('manage_bus_listing::manage_bus_listing.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('manage_bus_listing/manage_bus_listing/' . $manage_bus_listing->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/manage_bus_listing/manage_bus_listing'))
                ->redirect();
        }

    }

    /**
     * Show manage_bus_listing for editing.
     *
     * @param Request $request
     * @param Model   $manage_bus_listing
     *
     * @return Response
     */
    public function edit(ManageBusListingRequest $request, ManageBusListing $manage_bus_listing)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('manage_bus_listing::manage_bus_listing.name'))
            ->view('manage_bus_listing::manage_bus_listing.edit', true)
            ->data(compact('manage_bus_listing'))
            ->output();
    }

    /**
     * Update the manage_bus_listing.
     *
     * @param Request $request
     * @param Model   $manage_bus_listing
     *
     * @return Response
     */
    public function update(ManageBusListingRequest $request, ManageBusListing $manage_bus_listing)
    {
        try {
            $attributes = $request->all();

            $manage_bus_listing->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('manage_bus_listing::manage_bus_listing.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('manage_bus_listing/manage_bus_listing/' . $manage_bus_listing->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('manage_bus_listing/manage_bus_listing/' . $manage_bus_listing->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the manage_bus_listing.
     *
     * @param Model   $manage_bus_listing
     *
     * @return Response
     */
    public function destroy(ManageBusListingRequest $request, ManageBusListing $manage_bus_listing)
    {
        try {

            $manage_bus_listing->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('manage_bus_listing::manage_bus_listing.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('manage_bus_listing/manage_bus_listing/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('manage_bus_listing/manage_bus_listing/' . $manage_bus_listing->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple manage_bus_listing.
     *
     * @param Model   $manage_bus_listing
     *
     * @return Response
     */
    public function delete(ManageBusListingRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('manage_bus_listing::manage_bus_listing.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('manage_bus_listing/manage_bus_listing'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/manage_bus_listing/manage_bus_listing'))
                ->redirect();
        }

    }

    /**
     * Restore deleted manage_bus_listings.
     *
     * @param Model   $manage_bus_listing
     *
     * @return Response
     */
    public function restore(ManageBusListingRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('manage_bus_listing::manage_bus_listing.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/manage_bus_listing/manage_bus_listing'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/manage_bus_listing/manage_bus_listing/'))
                ->redirect();
        }

    }

}
