<?php

namespace Litecms\ManageBusListing\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\ManageBusListing\Models\ManageBusListing;

class ManageBusListingPolicy
{

    /**
     * Determine if the given user can view the manage_bus_listing.
     *
     * @param UserPolicy $user
     * @param ManageBusListing $manage_bus_listing
     *
     * @return bool
     */
    public function view(UserPolicy $user, ManageBusListing $manage_bus_listing)
    {
        if ($user->canDo('manage_bus_listing.manage_bus_listing.view') && $user->isAdmin()) {
            return true;
        }

        return $manage_bus_listing->user_id == user_id() && $manage_bus_listing->user_type == user_type();
    }

    /**
     * Determine if the given user can create a manage_bus_listing.
     *
     * @param UserPolicy $user
     * @param ManageBusListing $manage_bus_listing
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('manage_bus_listing.manage_bus_listing.create');
    }

    /**
     * Determine if the given user can update the given manage_bus_listing.
     *
     * @param UserPolicy $user
     * @param ManageBusListing $manage_bus_listing
     *
     * @return bool
     */
    public function update(UserPolicy $user, ManageBusListing $manage_bus_listing)
    {
        if ($user->canDo('manage_bus_listing.manage_bus_listing.edit') && $user->isAdmin()) {
            return true;
        }

        return $manage_bus_listing->user_id == user_id() && $manage_bus_listing->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given manage_bus_listing.
     *
     * @param UserPolicy $user
     * @param ManageBusListing $manage_bus_listing
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ManageBusListing $manage_bus_listing)
    {
        return $manage_bus_listing->user_id == user_id() && $manage_bus_listing->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given manage_bus_listing.
     *
     * @param UserPolicy $user
     * @param ManageBusListing $manage_bus_listing
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ManageBusListing $manage_bus_listing)
    {
        if ($user->canDo('manage_bus_listing.manage_bus_listing.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given manage_bus_listing.
     *
     * @param UserPolicy $user
     * @param ManageBusListing $manage_bus_listing
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ManageBusListing $manage_bus_listing)
    {
        if ($user->canDo('manage_bus_listing.manage_bus_listing.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
