<?php

namespace Litecms\ManageBusListing\Providers;

use Illuminate\Support\ServiceProvider;

class ManageBusListingServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'manage_bus_listing');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'manage_bus_listing');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.manage_bus_listing', function ($app) {
            return $this->app->make('Litecms\ManageBusListing\ManageBusListing');
        });

                // Bind ManageBusListing to repository
        $this->app->bind(
            'Litecms\ManageBusListing\Interfaces\ManageBusListingRepositoryInterface',
            \Litecms\ManageBusListing\Repositories\Eloquent\ManageBusListingRepository::class
        );

        $this->app->register(\Litecms\ManageBusListing\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\ManageBusListing\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\ManageBusListing\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.manage_bus_listing'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/manage_bus_listing.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/manage_bus_listing')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/manage_bus_listing')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
